@@ -21,7 +21,7 @@ echo ""
 echo "###################################################################"
 echo "###                                                             ###"
 echo "### 運用管理ソフトウェア Hinemos  エージェント                  ###"
-echo "###                                   インストーラ   Ver 2.2.2  ###"
+echo "###                                   インストーラ   Ver 2.3.1  ###"
 echo "###                                                             ###"
 echo "###  Copyright (C) 2006,2007 NTT DATA Corporation.              ###"
 echo "###################################################################"
@@ -46,19 +46,35 @@ pre_install() {
 	##
 	echo ""
 	echo "インストールを行う前に、${HOSTS_FILE} のチェックを行います。"
-	echo ""
-	
+
 	#ホスト名にIPアドレスの重複がないかチェックを行う
 	check_flg=`grep ${HOST} ${HOSTS_FILE} | grep -v ^\# | awk '{print $1}' | wc -l`
 	
 	if [ ${check_flg} != 1 ]; then
 	    echo "NG"
-	    echo "${HOSTS_FILE} は、${HOST} に対してIPアドレスの設定が行われていないか、2つ以上のIPアドレスが設定されています。"
-	    echo "一つの設定となるよう変更して下さい。"
+	    echo "${HOSTS_FILE} には、${HOST} に対してIPアドレスの設定が行われていないか、2つ以上のIPアドレスが設定されています。"
+	    echo "${HOSTS_FILE} を確認し、${HOST} とIPアドレスが1対1となるように設定を変更して下さい。"
 	    echo ""
-	    exit 1
+	    
+	    while [ 1 ]; do
+	    	echo "インストールを続けますか？（Y：続ける / N：中止する ）"
+	    	read ANS
+	    	case ${ANS} in
+	    		y|Y)
+	    	  		break
+	    	  	;;
+	    		n|N)
+			  		echo "インストールを中止します。"
+			  		echo ""
+			  		exit 1
+			  	;;
+		    	*)
+			esac
+		done
+		
+	else
+	    echo "OK"
 	fi
-	echo "OK"
 	
 	##
 	## hostsファイルのチェック END
@@ -299,10 +315,18 @@ do
 				  mv -f /etc/syslog-ng/syslog-ng.conf_tmp /etc/syslog-ng/syslog-ng.conf
 				  
 			  fi
-			  
-			  # syslogの停止・syslog-ngの起動
-			  /etc/init.d/syslog stop
-			  /etc/init.d/syslog-ng start
+
+			  # syslog-ngが既に起動していないか調べる
+			  /etc/init.d/syslog-ng status
+			  TMP_SYSLOGNG=$?
+			  if [ "${TMP_SYSLOGNG}" -eq 0 ] ; then
+			    # syslog-ngを再起動
+			    /etc/init.d/syslog-ng restart
+			  else
+			    # syslogの停止・syslog-ngの起動
+			    /etc/init.d/syslog stop
+			    /etc/init.d/syslog-ng start
+			  fi
 			  /sbin/chkconfig --level 2345 syslog off
 			  /sbin/chkconfig --level 2345 syslog-ng on
 			  
