@@ -15,7 +15,7 @@
 
 if [ -f $HINEMOS_AGENT_PID ] ; then
 	read AGENT_PID < $HINEMOS_AGENT_PID
-	ps -p $AGENT_PID e | grep $HINEMOS_AGENT_HOME > /dev/null && TMP=1
+	ps -p $AGENT_PID -f | grep $HINEMOS_AGENT_HOME > /dev/null && TMP=1
 	if [ "$TMP" ] ; then
 	        echo "Agent already started!"
         	exit 1
